/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D Programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.NSAppleScript;

import dwt.internal.cocoa.NSAppleEventDescriptor;
import dwt.internal.cocoa.NSObject;
import dwt.internal.cocoa.NSString;
import dwt.internal.cocoa.NSURL;
import dwt.internal.cocoa.OS;
import objc = dwt.internal.objc.runtime;

public class NSAppleScript : NSObject
{
    public this ()
    {
        super();
    }

    public this (objc.id id)
    {
        super(id);
    }

    public bool compileAndReturnError (objc.id** errorInfo)
    {
        return OS.objc_msgSend(this.id, OS.sel_compileAndReturnError_1, errorInfo) !is null;
    }

    public NSAppleEventDescriptor executeAndReturnError (objc.id** errorInfo)
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_executeAndReturnError_1, errorInfo);
        return result !is null ? new NSAppleEventDescriptor(result) : null;
    }

    public NSAppleEventDescriptor executeAppleEvent (NSAppleEventDescriptor event, objc.id** errorInfo)
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_executeAppleEvent_1error_1, event !is null ? event.id : null, errorInfo);
        return result !is null ? new NSAppleEventDescriptor(result) : null;
    }

    public NSAppleScript initWithContentsOfURL (NSURL url, objc.id** errorInfo)
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_initWithContentsOfURL_1error_1, url !is null ? url.id : null, errorInfo);
        return result !is null ? this : null;
    }

    public NSAppleScript initWithSource (NSString source)
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_initWithSource_1, source !is null ? source.id : null);
        return result !is null ? this : null;
    }

    public bool isCompiled ()
    {
        return OS.objc_msgSend(this.id, OS.sel_isCompiled) !is null;
    }

    public NSString source ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_source);
        return result !is null ? new NSString(result) : null;
    }
}
