/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D Programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.NSColorSpace;

import dwt.internal.cocoa.CGColorSpace;
import dwt.internal.cocoa.NSData;
import dwt.internal.cocoa.NSInteger;
import dwt.internal.cocoa.NSObject;
import dwt.internal.cocoa.NSString;
import dwt.internal.cocoa.OS;
import objc = dwt.internal.objc.runtime;

alias NSInteger NSColorSpaceModel;

enum
{
    NSUnknownColorSpaceModel = -1,
    NSGrayColorSpaceModel,
    NSRGBColorSpaceModel,
    NSCMYKColorSpaceModel,
    NSLABColorSpaceModel,
    NSDeviceNColorSpaceModel,
    NSIndexedColorSpaceModel,
    NSPatternColorSpaceModel
}

public class NSColorSpace : NSObject
{

    public this ()
    {
        super();
    }

    public this (objc.id id)
    {
        super(id);
    }

    public objc.id CGColorSpace ()
    {
        return OS.objc_msgSend(this.id, OS.sel_CGColorSpace);
    }

    public NSData ICCProfileData ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_ICCProfileData);
        return result !is null ? new NSData(result) : null;
    }

    public static NSColorSpace adobeRGB1998ColorSpace ()
    {
        objc.id result = OS.objc_msgSend(OS.class_NSColorSpace, OS.sel_adobeRGB1998ColorSpace);
        return result !is null ? new NSColorSpace(result) : null;
    }

    public NSColorSpaceModel colorSpaceModel ()
    {
        return OS.objc_msgSend(this.id, OS.sel_colorSpaceModel);
    }

    public void* colorSyncProfile ()
    {
        return OS.objc_msgSend(this.id, OS.sel_colorSyncProfile);
    }

    public static NSColorSpace deviceCMYKColorSpace ()
    {
        objc.id result = OS.objc_msgSend(OS.class_NSColorSpace, OS.sel_deviceCMYKColorSpace);
        return result !is null ? new NSColorSpace(result) : null;
    }

    public static NSColorSpace deviceGrayColorSpace ()
    {
        objc.id result = OS.objc_msgSend(OS.class_NSColorSpace, OS.sel_deviceGrayColorSpace);
        return result !is null ? new NSColorSpace(result) : null;
    }

    public static NSColorSpace deviceRGBColorSpace ()
    {
        objc.id result = OS.objc_msgSend(OS.class_NSColorSpace, OS.sel_deviceRGBColorSpace);
        return result !is null ? new NSColorSpace(result) : null;
    }

    public static NSColorSpace genericCMYKColorSpace ()
    {
        objc.id result = OS.objc_msgSend(OS.class_NSColorSpace, OS.sel_genericCMYKColorSpace);
        return result !is null ? new NSColorSpace(result) : null;
    }

    public static NSColorSpace genericGrayColorSpace ()
    {
        objc.id result = OS.objc_msgSend(OS.class_NSColorSpace, OS.sel_genericGrayColorSpace);
        return result !is null ? new NSColorSpace(result) : null;
    }

    public static NSColorSpace genericRGBColorSpace ()
    {
        objc.id result = OS.objc_msgSend(OS.class_NSColorSpace, OS.sel_genericRGBColorSpace);
        return result !is null ? new NSColorSpace(result) : null;
    }

    public NSColorSpace initWithCGColorSpace (CGColorSpaceRef cgColorSpace)
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_initWithCGColorSpace_1, cgColorSpace);
        return result !is null ? this : null;
    }

    public NSColorSpace initWithColorSyncProfile (void* prof)
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_initWithColorSyncProfile_1, prof);
        return result !is null ? this : null;
    }

    public NSColorSpace initWithICCProfileData (NSData iccData)
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_initWithICCProfileData_1, iccData !is null ? iccData.id : null);
        return result !is null ? this : null;
    }

    public NSString localizedName ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_localizedName);
        return result !is null ? new NSString(result) : null;
    }

    public NSInteger numberOfColorComponents ()
    {
        return OS.objc_msgSend(this.id, OS.sel_numberOfColorComponents);
    }

    public static NSColorSpace sRGBColorSpace ()
    {
        objc.id result = OS.objc_msgSend(OS.class_NSColorSpace, OS.sel_sRGBColorSpace);
        return result !is null ? new NSColorSpace(result) : null;
    }

}
