/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D Programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.NSDateFormatter;

import dwt.internal.cocoa.NSArray;
import dwt.internal.cocoa.NSCalendar;
import dwt.internal.cocoa.NSDate;
import dwt.internal.cocoa.NSFormatter;
import dwt.internal.cocoa.NSLocale;
import dwt.internal.cocoa.NSRange;
import dwt.internal.cocoa.NSString;
import dwt.internal.cocoa.NSTimeZone;
import dwt.internal.cocoa.OS;
import objc = dwt.internal.objc.runtime;

public class NSDateFormatter : NSFormatter
{
    public this ()
    {
        super();
    }

    public this (objc.id id)
    {
        super(id);
    }

    public NSString AMSymbol ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_AMSymbol);
        return result !is null ? new NSString(result) : null;
    }

    public NSString PMSymbol ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_PMSymbol);
        return result !is null ? new NSString(result) : null;
    }

    public bool allowsNaturalLanguage ()
    {
        return OS.objc_msgSend(this.id, OS.sel_allowsNaturalLanguage) !is null;
    }

    public NSCalendar calendar ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_calendar);
        return result !is null ? new NSCalendar(result) : null;
    }

    public NSString dateFormat ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_dateFormat);
        return result !is null ? new NSString(result) : null;
    }

    public NSDate dateFromString (NSString string)
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_dateFromString_1, string !is null ? string.id : null);
        return result !is null ? new NSDate(result) : null;
    }

    public objc.id dateStyle ()
    {
        return OS.objc_msgSend(this.id, OS.sel_dateStyle);
    }

    public NSDate defaultDate ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_defaultDate);
        return result !is null ? new NSDate(result) : null;
    }

    public static objc.id defaultFormatterBehavior ()
    {
        return OS.objc_msgSend(OS.class_NSDateFormatter, OS.sel_defaultFormatterBehavior);
    }

    public NSArray eraSymbols ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_eraSymbols);
        return result !is null ? new NSArray(result) : null;
    }

    public objc.id formatterBehavior ()
    {
        return OS.objc_msgSend(this.id, OS.sel_formatterBehavior);
    }

    public bool generatesCalendarDates ()
    {
        return OS.objc_msgSend(this.id, OS.sel_generatesCalendarDates) !is null;
    }

    public bool getObjectValue (objc.id* obj, NSString string, NSRange* rangep, objc.id** error)
    {
        return OS.objc_msgSend(this.id, OS.sel_getObjectValue_1forString_1range_1error_1, obj, string !is null ? string.id : null, rangep, error) !is null;
    }

    public NSDate gregorianStartDate ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_gregorianStartDate);
        return result !is null ? new NSDate(result) : null;
    }

    public id initWithDateFormat (NSString format, bool flag)
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_initWithDateFormat_1allowNaturalLanguage_1, format !is null ? format.id : null, flag);
        return result !is null ? new id(result) : null;
    }

    public bool isLenient ()
    {
        return OS.objc_msgSend(this.id, OS.sel_isLenient) !is null;
    }

    public NSLocale locale ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_locale);
        return result !is null ? new NSLocale(result) : null;
    }

    public NSArray longEraSymbols ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_longEraSymbols);
        return result !is null ? new NSArray(result) : null;
    }

    public NSArray monthSymbols ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_monthSymbols);
        return result !is null ? new NSArray(result) : null;
    }

    public NSArray quarterSymbols ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_quarterSymbols);
        return result !is null ? new NSArray(result) : null;
    }

    public void setAMSymbol (NSString string)
    {
        OS.objc_msgSend(this.id, OS.sel_setAMSymbol_1, string !is null ? string.id : null);
    }

    public void setCalendar (NSCalendar calendar)
    {
        OS.objc_msgSend(this.id, OS.sel_setCalendar_1, calendar !is null ? calendar.id : null);
    }

    public void setDateFormat (NSString string)
    {
        OS.objc_msgSend(this.id, OS.sel_setDateFormat_1, string !is null ? string.id : null);
    }

    public void setDateStyle (objc.id style)
    {
        OS.objc_msgSend(this.id, OS.sel_setDateStyle_1, style);
    }

    public void setDefaultDate (NSDate date)
    {
        OS.objc_msgSend(this.id, OS.sel_setDefaultDate_1, date !is null ? date.id : null);
    }

    public static void setDefaultFormatterBehavior (objc.id behavior)
    {
        OS.objc_msgSend(OS.class_NSDateFormatter, OS.sel_setDefaultFormatterBehavior_1, behavior);
    }

    public void setEraSymbols (NSArray array)
    {
        OS.objc_msgSend(this.id, OS.sel_setEraSymbols_1, array !is null ? array.id : null);
    }

    public void setFormatterBehavior (objc.id behavior)
    {
        OS.objc_msgSend(this.id, OS.sel_setFormatterBehavior_1, behavior);
    }

    public void setGeneratesCalendarDates (bool b)
    {
        OS.objc_msgSend(this.id, OS.sel_setGeneratesCalendarDates_1, b);
    }

    public void setGregorianStartDate (NSDate date)
    {
        OS.objc_msgSend(this.id, OS.sel_setGregorianStartDate_1, date !is null ? date.id : null);
    }

    public void setLenient (bool b)
    {
        OS.objc_msgSend(this.id, OS.sel_setLenient_1, b);
    }

    public void setLocale (NSLocale locale)
    {
        OS.objc_msgSend(this.id, OS.sel_setLocale_1, locale !is null ? locale.id : null);
    }

    public void setLongEraSymbols (NSArray array)
    {
        OS.objc_msgSend(this.id, OS.sel_setLongEraSymbols_1, array !is null ? array.id : null);
    }

    public void setMonthSymbols (NSArray array)
    {
        OS.objc_msgSend(this.id, OS.sel_setMonthSymbols_1, array !is null ? array.id : null);
    }

    public void setPMSymbol (NSString string)
    {
        OS.objc_msgSend(this.id, OS.sel_setPMSymbol_1, string !is null ? string.id : null);
    }

    public void setQuarterSymbols (NSArray array)
    {
        OS.objc_msgSend(this.id, OS.sel_setQuarterSymbols_1, array !is null ? array.id : null);
    }

    public void setShortMonthSymbols (NSArray array)
    {
        OS.objc_msgSend(this.id, OS.sel_setShortMonthSymbols_1, array !is null ? array.id : null);
    }

    public void setShortQuarterSymbols (NSArray array)
    {
        OS.objc_msgSend(this.id, OS.sel_setShortQuarterSymbols_1, array !is null ? array.id : null);
    }

    public void setShortStandaloneMonthSymbols (NSArray array)
    {
        OS.objc_msgSend(this.id, OS.sel_setShortStandaloneMonthSymbols_1, array !is null ? array.id : null);
    }

    public void setShortStandaloneQuarterSymbols (NSArray array)
    {
        OS.objc_msgSend(this.id, OS.sel_setShortStandaloneQuarterSymbols_1, array !is null ? array.id : null);
    }

    public void setShortStandaloneWeekdaySymbols (NSArray array)
    {
        OS.objc_msgSend(this.id, OS.sel_setShortStandaloneWeekdaySymbols_1, array !is null ? array.id : null);
    }

    public void setShortWeekdaySymbols (NSArray array)
    {
        OS.objc_msgSend(this.id, OS.sel_setShortWeekdaySymbols_1, array !is null ? array.id : null);
    }

    public void setStandaloneMonthSymbols (NSArray array)
    {
        OS.objc_msgSend(this.id, OS.sel_setStandaloneMonthSymbols_1, array !is null ? array.id : null);
    }

    public void setStandaloneQuarterSymbols (NSArray array)
    {
        OS.objc_msgSend(this.id, OS.sel_setStandaloneQuarterSymbols_1, array !is null ? array.id : null);
    }

    public void setStandaloneWeekdaySymbols (NSArray array)
    {
        OS.objc_msgSend(this.id, OS.sel_setStandaloneWeekdaySymbols_1, array !is null ? array.id : null);
    }

    public void setTimeStyle (objc.id style)
    {
        OS.objc_msgSend(this.id, OS.sel_setTimeStyle_1, style);
    }

    public void setTimeZone (NSTimeZone tz)
    {
        OS.objc_msgSend(this.id, OS.sel_setTimeZone_1, tz !is null ? tz.id : null);
    }

    public void setTwoDigitStartDate (NSDate date)
    {
        OS.objc_msgSend(this.id, OS.sel_setTwoDigitStartDate_1, date !is null ? date.id : null);
    }

    public void setVeryShortMonthSymbols (NSArray array)
    {
        OS.objc_msgSend(this.id, OS.sel_setVeryShortMonthSymbols_1, array !is null ? array.id : null);
    }

    public void setVeryShortStandaloneMonthSymbols (NSArray array)
    {
        OS.objc_msgSend(this.id, OS.sel_setVeryShortStandaloneMonthSymbols_1, array !is null ? array.id : null);
    }

    public void setVeryShortStandaloneWeekdaySymbols (NSArray array)
    {
        OS.objc_msgSend(this.id, OS.sel_setVeryShortStandaloneWeekdaySymbols_1, array !is null ? array.id : null);
    }

    public void setVeryShortWeekdaySymbols (NSArray array)
    {
        OS.objc_msgSend(this.id, OS.sel_setVeryShortWeekdaySymbols_1, array !is null ? array.id : null);
    }

    public void setWeekdaySymbols (NSArray array)
    {
        OS.objc_msgSend(this.id, OS.sel_setWeekdaySymbols_1, array !is null ? array.id : null);
    }

    public NSArray shortMonthSymbols ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_shortMonthSymbols);
        return result !is null ? new NSArray(result) : null;
    }

    public NSArray shortQuarterSymbols ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_shortQuarterSymbols);
        return result !is null ? new NSArray(result) : null;
    }

    public NSArray shortStandaloneMonthSymbols ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_shortStandaloneMonthSymbols);
        return result !is null ? new NSArray(result) : null;
    }

    public NSArray shortStandaloneQuarterSymbols ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_shortStandaloneQuarterSymbols);
        return result !is null ? new NSArray(result) : null;
    }

    public NSArray shortStandaloneWeekdaySymbols ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_shortStandaloneWeekdaySymbols);
        return result !is null ? new NSArray(result) : null;
    }

    public NSArray shortWeekdaySymbols ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_shortWeekdaySymbols);
        return result !is null ? new NSArray(result) : null;
    }

    public NSArray standaloneMonthSymbols ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_standaloneMonthSymbols);
        return result !is null ? new NSArray(result) : null;
    }

    public NSArray standaloneQuarterSymbols ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_standaloneQuarterSymbols);
        return result !is null ? new NSArray(result) : null;
    }

    public NSArray standaloneWeekdaySymbols ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_standaloneWeekdaySymbols);
        return result !is null ? new NSArray(result) : null;
    }

    public NSString stringFromDate (NSDate date)
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_stringFromDate_1, date !is null ? date.id : null);
        return result !is null ? new NSString(result) : null;
    }

    public objc.id timeStyle ()
    {
        return OS.objc_msgSend(this.id, OS.sel_timeStyle);
    }

    public NSTimeZone timeZone ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_timeZone);
        return result !is null ? new NSTimeZone(result) : null;
    }

    public NSDate twoDigitStartDate ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_twoDigitStartDate);
        return result !is null ? new NSDate(result) : null;
    }

    public NSArray veryShortMonthSymbols ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_veryShortMonthSymbols);
        return result !is null ? new NSArray(result) : null;
    }

    public NSArray veryShortStandaloneMonthSymbols ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_veryShortStandaloneMonthSymbols);
        return result !is null ? new NSArray(result) : null;
    }

    public NSArray veryShortStandaloneWeekdaySymbols ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_veryShortStandaloneWeekdaySymbols);
        return result !is null ? new NSArray(result) : null;
    }

    public NSArray veryShortWeekdaySymbols ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_veryShortWeekdaySymbols);
        return result !is null ? new NSArray(result) : null;
    }

    public NSArray weekdaySymbols ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_weekdaySymbols);
        return result !is null ? new NSArray(result) : null;
    }
}
