/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D Programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.NSPathCell;

import dwt.internal.cocoa.NSActionCell;
import dwt.internal.cocoa.NSArray;
import dwt.internal.cocoa.NSAttributedString;
import dwt.internal.cocoa.NSCell : NSControlSize;
import dwt.internal.cocoa.NSColor;
import dwt.internal.cocoa.NSEvent;
import dwt.internal.cocoa.NSInteger;
import dwt.internal.cocoa.NSPathComponentCell;
import dwt.internal.cocoa.NSPoint;
import dwt.internal.cocoa.NSRect;
import dwt.internal.cocoa.NSURL;
import dwt.internal.cocoa.NSView;
import dwt.internal.cocoa.OS;
import objc = dwt.internal.objc.runtime;

enum
{
    NSPathStyleStandard,
    NSPathStyleNavigationBar,
    NSPathStylePopUp,
}

alias NSInteger NSPathStyle;

public class NSPathCell : NSActionCell
{

    public this ()
    {
        super();
    }

    public this (objc.id id)
    {
        super(id);
    }

    public NSURL URL ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_URL);
        return result !is null ? new NSURL(result) : null;
    }

    public NSArray allowedTypes ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_allowedTypes);
        return result !is null ? new NSArray(result) : null;
    }

    public NSColor backgroundColor ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_backgroundColor);
        return result !is null ? new NSColor(result) : null;
    }

    public NSPathComponentCell clickedPathComponentCell ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_clickedPathComponentCell);
        return result !is null ? new NSPathComponentCell(result) : null;
    }

    public id delegatee ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_delegate);
        return result !is null ? new id(result) : null;
    }

    public objc.SEL doubleAction ()
    {
        return OS.objc_msgSend(this.id, OS.sel_doubleAction);
    }

    public void mouseEntered (NSEvent event, NSRect frame, NSView view)
    {
        OS.objc_msgSend(this.id, OS.sel_mouseEntered_1withFrame_1inView_1, event !is null ? event.id : null, frame, view !is null ? view.id : null);
    }

    public void mouseExited (NSEvent event, NSRect frame, NSView view)
    {
        OS.objc_msgSend(this.id, OS.sel_mouseExited_1withFrame_1inView_1, event !is null ? event.id : null, frame, view !is null ? view.id : null);
    }

    public NSPathComponentCell pathComponentCellAtPoint (NSPoint point, NSRect frame, NSView view)
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_pathComponentCellAtPoint_1withFrame_1inView_1, point, frame, view !is null ? view.id : null);
        return result !is null ? new NSPathComponentCell(result) : null;
    }

    public static objc.Class pathComponentCellClass ()
    {
        return cast(objc.Class) OS.objc_msgSend(OS.class_NSPathCell, OS.sel_pathComponentCellClass);
    }

    public NSArray pathComponentCells ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_pathComponentCells);
        return result !is null ? new NSArray(result) : null;
    }

    public NSPathStyle pathStyle ()
    {
        return OS.objc_msgSend(this.id, OS.sel_pathStyle);
    }

    public NSAttributedString placeholderAttributedString ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_placeholderAttributedString);
        return result !is null ? new NSAttributedString(result) : null;
    }

    public NSString placeholderString ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_placeholderString);
        return result !is null ? new NSString(result) : null;
    }

    public NSRect rectOfPathComponentCell (NSPathComponentCell cell, NSRect frame, NSView view)
    {
        NSRect result;
        OS.objc_msgSend_stret(result, this.id, OS.sel_rectOfPathComponentCell_1withFrame_1inView_1, cell !is null ? cell.id : null, frame,
                view !is null ? view.id : null);
        return result;
    }

    public void setAllowedTypes (NSArray allowedTypes)
    {
        OS.objc_msgSend(this.id, OS.sel_setAllowedTypes_1, allowedTypes !is null ? allowedTypes.id : null);
    }

    public void setBackgroundColor (NSColor color)
    {
        OS.objc_msgSend(this.id, OS.sel_setBackgroundColor_1, color !is null ? color.id : null);
    }

    public void setControlSize (NSControlSize size)
    {
        OS.objc_msgSend(this.id, OS.sel_setControlSize_1, size);
    }

    public void setDelegate (id value)
    {
        OS.objc_msgSend(this.id, OS.sel_setDelegate_1, value !is null ? value.id : null);
    }

    public void setDoubleAction (objc.SEL action)
    {
        OS.objc_msgSend(this.id, OS.sel_setDoubleAction_1, action);
    }

    public void setObjectValue (id obj)
    {
        OS.objc_msgSend(this.id, OS.sel_setObjectValue_1, obj !is null ? obj.id : null);
    }

    public void setPathComponentCells (NSArray cells)
    {
        OS.objc_msgSend(this.id, OS.sel_setPathComponentCells_1, cells !is null ? cells.id : null);
    }

    public void setPathStyle (NSPathStyle style)
    {
        OS.objc_msgSend(this.id, OS.sel_setPathStyle_1, style);
    }

    public void setPlaceholderAttributedString (NSAttributedString string)
    {
        OS.objc_msgSend(this.id, OS.sel_setPlaceholderAttributedString_1, string !is null ? string.id : null);
    }

    public void setPlaceholderString (NSString string)
    {
        OS.objc_msgSend(this.id, OS.sel_setPlaceholderString_1, string !is null ? string.id : null);
    }

    public void setURL (NSURL url)
    {
        OS.objc_msgSend(this.id, OS.sel_setURL_1, url !is null ? url.id : null);
    }

}
