/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D Programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.NSPropertyListSerialization;

import dwt.internal.cocoa.CFPropertyList;
import dwt.internal.cocoa.NSData;
import dwt.internal.cocoa.NSObject;
import dwt.internal.cocoa.OS;
import objc = dwt.internal.objc.runtime;

enum NSPropertyListFormat
{
    NSPropertyListOpenStepFormat = kCFPropertyListOpenStepFormat,
    NSPropertyListXMLFormat_v1_0 = kCFPropertyListXMLFormat_v1_0,
    NSPropertyListBinaryFormat_v1_0 = kCFPropertyListBinaryFormat_v1_0
}

alias NSPropertyListFormat.NSPropertyListOpenStepFormat NSPropertyListOpenStepFormat;
alias NSPropertyListFormat.NSPropertyListXMLFormat_v1_0 NSPropertyListXMLFormat_v1_0;
alias NSPropertyListFormat.NSPropertyListBinaryFormat_v1_0 NSPropertyListBinaryFormat_v1_0;

enum NSPropertyListMutabilityOptions
{
    NSPropertyListImmutable = kCFPropertyListImmutable,
    NSPropertyListMutableContainers = kCFPropertyListMutableContainers,
    NSPropertyListMutableContainersAndLeaves = kCFPropertyListMutableContainersAndLeaves
}

alias NSPropertyListMutabilityOptions.NSPropertyListImmutable NSPropertyListImmutable;
alias NSPropertyListMutabilityOptions.NSPropertyListMutableContainers NSPropertyListMutableContainers;
alias NSPropertyListMutabilityOptions.NSPropertyListMutableContainersAndLeaves NSPropertyListMutableContainersAndLeaves;

public class NSPropertyListSerialization : NSObject
{

    public this ()
    {
        super();
    }

    public this (objc.id id)
    {
        super(id);
    }

    public static NSData dataFromPropertyList (id plist, NSPropertyListFormat format, objc.id** errorString)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSPropertyListSerialization, OS.sel_dataFromPropertyList_1format_1errorDescription_1,
                plist !is null ? plist.id : null, format, errorString);
        return result !is null ? new NSData(result) : null;
    }

    public static bool propertyList (id plist, NSPropertyListFormat format)
    {
        return OS.objc_msgSend(OS.class_NSPropertyListSerialization, OS.sel_propertyList_1isValidForFormat_1, plist !is null ? plist.id : null,
                format) !is null;
    }

    public static id propertyListFromData (NSData data, NSPropertyListMutabilityOptions opt, NSPropertyListFormat* format, objc.id** errorString)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSPropertyListSerialization,
                OS.sel_propertyListFromData_1mutabilityOption_1format_1errorDescription_1, data !is null ? data.id : null, opt, format, errorString);
        return result !is null ? new id(result) : null;
    }

}
