/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D Programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.NSScriptClassDescription;

import dwt.internal.c.carboncore.MacTypes : FourCharCode;
import dwt.internal.cocoa.id;
import dwt.internal.cocoa.NSClassDescription;
import dwt.internal.cocoa.NSDictionary;
import dwt.internal.cocoa.NSScriptCommandDescription;
import dwt.internal.cocoa.NSString;
import dwt.internal.cocoa.OS;
import objc = dwt.internal.objc.runtime;

public class NSScriptClassDescription : NSClassDescription
{

    public this ()
    {
        super();
    }

    public this (objc.id id)
    {
        super(id);
    }

    public FourCharCode appleEventCode ()
    {
        return cast(FourCharCode) OS.objc_msgSend(this.id, OS.sel_appleEventCode);
    }

    public FourCharCode appleEventCodeForKey (NSString key)
    {
        return cast(FourCharCode) OS.objc_msgSend(this.id, OS.sel_appleEventCodeForKey_1, key !is null ? key.id : null);
    }

    //public static NSScriptClassDescription classDescriptionForClass(int aClass) {
    //  objc.id result = OS.objc_msgSend(OS.class_NSScriptClassDescription, OS.sel_classDescriptionForClass_1, aClass);
    //  return result !is null ? new NSScriptClassDescription(result) : null;
    //}

    public NSScriptClassDescription classDescriptionForKey (NSString key)
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_classDescriptionForKey_1, key !is null ? key.id : null);
        return result is this.id ? this : (result !is null ? new NSScriptClassDescription(result) : null);
    }

    public NSString className ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_className);
        return result !is null ? new NSString(result) : null;
    }

    public NSString defaultSubcontainerAttributeKey ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_defaultSubcontainerAttributeKey);
        return result !is null ? new NSString(result) : null;
    }

    public bool hasOrderedToManyRelationshipForKey (NSString key)
    {
        return OS.objc_msgSend(this.id, OS.sel_hasOrderedToManyRelationshipForKey_1, key !is null ? key.id : null) !is null;
    }

    public bool hasPropertyForKey (NSString key)
    {
        return OS.objc_msgSend(this.id, OS.sel_hasPropertyForKey_1, key !is null ? key.id : null) !is null;
    }

    public bool hasReadablePropertyForKey (NSString key)
    {
        return OS.objc_msgSend(this.id, OS.sel_hasReadablePropertyForKey_1, key !is null ? key.id : null) !is null;
    }

    public bool hasWritablePropertyForKey (NSString key)
    {
        return OS.objc_msgSend(this.id, OS.sel_hasWritablePropertyForKey_1, key !is null ? key.id : null) !is null;
    }

    public NSString implementationClassName ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_implementationClassName);
        return result !is null ? new NSString(result) : null;
    }

    public id initWithSuiteName (NSString suiteName, NSString className, NSDictionary classDeclaration)
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_initWithSuiteName_1className_1dictionary_1, suiteName !is null ? suiteName.id : null,
                className !is null ? className.id : null, classDeclaration !is null ? classDeclaration.id : null);
        return result !is null ? new id(result) : null;
    }

    public bool isLocationRequiredToCreateForKey (NSString toManyRelationshipKey)
    {
        return OS.objc_msgSend(this.id, OS.sel_isLocationRequiredToCreateForKey_1, toManyRelationshipKey !is null ? toManyRelationshipKey.id : null) !is null;
    }

    public bool isReadOnlyKey (NSString key)
    {
        return OS.objc_msgSend(this.id, OS.sel_isReadOnlyKey_1, key !is null ? key.id : null) !is null;
    }

    public NSString keyWithAppleEventCode (FourCharCode appleEventCode)
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_keyWithAppleEventCode_1, appleEventCode);
        return result !is null ? new NSString(result) : null;
    }

    public bool matchesAppleEventCode (FourCharCode appleEventCode)
    {
        return OS.objc_msgSend(this.id, OS.sel_matchesAppleEventCode_1, appleEventCode) !is null;
    }

    public int selectorForCommand (NSScriptCommandDescription commandDescription)
    {
        return OS.objc_msgSend(this.id, OS.sel_selectorForCommand_1, commandDescription !is null ? commandDescription.id : null);
    }

    public NSString suiteName ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_suiteName);
        return result !is null ? new NSString(result) : null;
    }

    public NSScriptClassDescription superclassDescription ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_superclassDescription);
        return result is this.id ? this : (result !is null ? new NSScriptClassDescription(result) : null);
    }

    public bool supportsCommand (NSScriptCommandDescription commandDescription)
    {
        return OS.objc_msgSend(this.id, OS.sel_supportsCommand_1, commandDescription !is null ? commandDescription.id : null) !is null;
    }

    public NSString typeForKey (NSString key)
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_typeForKey_1, key !is null ? key.id : null);
        return result !is null ? new NSString(result) : null;
    }

}
