/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D Programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.NSTreeNode;

import dwt.internal.cocoa.id;
import dwt.internal.cocoa.NSArray;
import dwt.internal.cocoa.NSIndexPath;
import dwt.internal.cocoa.NSMutableArray;
import dwt.internal.cocoa.NSObject;
import dwt.internal.cocoa.OS;
import objc = dwt.internal.objc.runtime;

public class NSTreeNode : NSObject
{

    public this ()
    {
        super();
    }

    public this (objc.id id)
    {
        super(id);
    }

    public NSArray childNodes ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_childNodes);
        return result !is null ? new NSArray(result) : null;
    }

    public NSTreeNode descendantNodeAtIndexPath (NSIndexPath indexPath)
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_descendantNodeAtIndexPath_1, indexPath !is null ? indexPath.id : null);
        return result is this.id ? this : (result !is null ? new NSTreeNode(result) : null);
    }

    public NSIndexPath indexPath ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_indexPath);
        return result !is null ? new NSIndexPath(result) : null;
    }

    public id initWithRepresentedObject (id modelObject)
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_initWithRepresentedObject_1, modelObject !is null ? modelObject.id : null);
        return result !is null ? new id(result) : null;
    }

    public bool isLeaf ()
    {
        return OS.objc_msgSend(this.id, OS.sel_isLeaf) !is null;
    }

    public NSMutableArray mutableChildNodes ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_mutableChildNodes);
        return result !is null ? new NSMutableArray(result) : null;
    }

    public NSTreeNode parentNode ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_parentNode);
        return result is this.id ? this : (result !is null ? new NSTreeNode(result) : null);
    }

    public id representedObject ()
    {
        objc.id result = OS.objc_msgSend(this.id, OS.sel_representedObject);
        return result !is null ? new id(result) : null;
    }

    public void sortWithSortDescriptors (NSArray sortDescriptors, bool recursively)
    {
        OS.objc_msgSend(this.id, OS.sel_sortWithSortDescriptors_1recursively_1, sortDescriptors !is null ? sortDescriptors.id : null, recursively);
    }

    public static id treeNodeWithRepresentedObject (id modelObject)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSTreeNode, OS.sel_treeNodeWithRepresentedObject_1, modelObject !is null ? modelObject.id : null);
        return result !is null ? new id(result) : null;
    }

}
